summaryrefslogtreecommitdiffstats
path: root/libkdegames/kchatbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kchatbase.h')
-rw-r--r--libkdegames/kchatbase.h45
1 files changed, 23 insertions, 22 deletions
diff --git a/libkdegames/kchatbase.h b/libkdegames/kchatbase.h
index 7dc5ff59..5e97b80c 100644
--- a/libkdegames/kchatbase.h
+++ b/libkdegames/kchatbase.h
@@ -46,7 +46,7 @@ class KChatBaseTextPrivate;
* will probably some kind of KChatBaseDialog which offers the user the ability
* to configure things like color and font on the fly.
**/
-class KChatBaseText : public QListBoxText
+class KChatBaseText : public TQListBoxText
{
public:
@@ -171,8 +171,8 @@ class KChatBasePrivate;
*
* To add a message just call addMessage with the nickname of the player
* who sent the message and the message itself. If you don't want to use
* layoutMessage by any reason you can also call addItem directly. But you
* should better replace layoutMessage instead.
*
* You probably don't want to use the abstract class KChatBase directly but use
* one of the derived classess KChat or KGameChat. The latter is the
@@ -181,17 +181,18 @@ class KChatBasePrivate;
*
* @author Andreas Beckermann <b_mann@gmx.de>
**/
-class KDE_EXPORT KChatBase : public QFrame
+class KDE_EXPORT KChatBase : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param parent The parent widget for this widget.
* @param noComboBox If true then the combo box where the player can
* choose where to send messages to (either globally or just to some
* players) will not be added.
**/
- KChatBase(TQWidget* parent, bool noComboBox = false);
+ KChatBase(TQWidget* tqparent, bool noComboBox = false);
/**
* Destruct the KChatBase object
@@ -313,35 +314,35 @@ public:
/**
* Same as setNameFont but applies only to system messages.
- * @see layoutSystemMessage
+ * @see tqlayoutSystemMessage
**/
void setSystemNameFont(const TQFont& font);
/**
* Same as setMessageFont but applies only to system messages.
- * @see layoutSystemMessage
+ * @see tqlayoutSystemMessage
**/
void setSystemMessageFont(const TQFont& font);
/**
* Same as setBothFont but applies only to system messages.
- * @see layoutSystemMessage
+ * @see tqlayoutSystemMessage
**/
void setSystemBothFont(const TQFont& font);
/**
* This font should be used for the name (the "from: " part) of a
* message. layoutMessage uses this to set the font using
* KChatBaseText::setNameFont but if you want to overwrite
* layoutMessage you should do this yourself.
* @return The font that is used for the name part of the message.
**/
const TQFont& nameFont() const;
/**
* This font should be used for a message. layoutMessage sets the
* font of a message using KChatBaseText::setMessageFont but if ypu
* replace layoutMessage with your own function you should use
* messageFont() yourself.
* @return The font that is used for a message
**/
@@ -349,13 +350,13 @@ public:
/**
* Same as systemNameFont but applies only to system messages.
- * @see layoutSystemMessage
+ * @see tqlayoutSystemMessage
**/
const TQFont& systemNameFont() const;
/**
* Same as systemMessageFont but applies only to system messages.
- * @see layoutSystemMessage
+ * @see tqlayoutSystemMessage
**/
const TQFont& systemMessageFont() const;
@@ -405,7 +406,7 @@ public slots:
* Maybe you want to replace this with a function that creates a nicer text
* than "fromName: text"
*
* Update: the function layoutMessage is called by this now. This
* means that you will get user defined outlook on the messages :-)
* @param fromName The player who sent this message
* @param text The text to be added
@@ -414,7 +415,7 @@ public slots:
/**
* This works just like addMessage but adds a system message.
* layoutSystemMessage is used to generate the displayed item. System
* messages will have a different look than player messages.
*
* You may wish to use this to display status information from your game.
@@ -470,7 +471,7 @@ protected:
/**
* Replace to customise the combo box.
*
- * Default: i18n("Send to %1).arg(name)
+ * Default: i18n("Send to %1).tqarg(name)
* @param name The name of the player
* @return The string as it will be shown in the combo box
**/
@@ -478,20 +479,20 @@ protected:
/**
* Create a TQListBoxItem for this message. This function is not yet
- * written usefully - currently just a QListBoxTex object is
+ * written usefully - currently just a TQListBoxTex object is
* created which shows the message in this format: "fromName: text".
* This should fit most peoples needs but needs further improvements.
**/
- virtual TQListBoxItem* layoutMessage(const TQString& fromName, const TQString& text);
+ virtual TQListBoxItem* tqlayoutMessage(const TQString& fromName, const TQString& text);
/**
* Create a TQListBoxItem for this message. This does the same as
* layoutMessage but generates a system message. You might want to
* use such a message to display e.g. status information from your game.
*
* The default implementation just prepends "--- ".
**/
- virtual TQListBoxItem* layoutSystemMessage(const TQString& fromName, const TQString& text);
+ virtual TQListBoxItem* tqlayoutSystemMessage(const TQString& fromName, const TQString& text);
private slots:
/**
@@ -171,8 +171,8 @@ class KChatBasePrivate;
* To add a message just call addMessage with the nickname of the player
* who sent the message and the message itself. If you don't want to use
- * layoutMessage by any reason you can also call addItem directly. But you
- * should better replace layoutMessage instead.
+ * tqlayoutMessage by any reason you can also call addItem directly. But you
+ * should better replace tqlayoutMessage instead.
*
* You probably don't want to use the abstract class KChatBase directly but use
@@ -181,17 +181,18 @@ class KChatBasePrivate;
public:
/**
- * @param parent The parent widget for this widget.
+ * @param tqparent The tqparent widget for this widget.
* @param noComboBox If true then the combo box where the player can
* choose where to send messages to (either globally or just to some
@@ -313,35 +314,35 @@ public:
/**
* This font should be used for the name (the "from: " part) of a
- * message. layoutMessage uses this to set the font using
+ * message. tqlayoutMessage uses this to set the font using
* KChatBaseText::setNameFont but if you want to overwrite
@@ -313,35 +314,35 @@ public:
* KChatBaseText::setNameFont but if you want to overwrite
- * layoutMessage you should do this yourself.
+ * tqlayoutMessage you should do this yourself.
* @return The font that is used for the name part of the message.
**/
@@ -313,35 +314,35 @@ public:
const TQFont& nameFont() const;
/**
- * This font should be used for a message. layoutMessage sets the
+ * This font should be used for a message. tqlayoutMessage sets the
* font of a message using KChatBaseText::setMessageFont but if ypu
@@ -313,35 +314,35 @@ public:
* font of a message using KChatBaseText::setMessageFont but if ypu
- * replace layoutMessage with your own function you should use
+ * replace tqlayoutMessage with your own function you should use
* messageFont() yourself.
* @return The font that is used for a message
@@ -405,7 +406,7 @@ public slots:
* than "fromName: text"
*
- * Update: the function layoutMessage is called by this now. This
+ * Update: the function tqlayoutMessage is called by this now. This
* means that you will get user defined outlook on the messages :-)
* @param fromName The player who sent this message
@@ -414,7 +415,7 @@ public slots:
/**
* This works just like addMessage but adds a system message.
- * layoutSystemMessage is used to generate the displayed item. System
+ * tqlayoutSystemMessage is used to generate the displayed item. System
* messages will have a different look than player messages.
*
@@ -478,20 +479,20 @@ protected:
/**
* Create a TQListBoxItem for this message. This does the same as
- * layoutMessage but generates a system message. You might want to
+ * tqlayoutMessage but generates a system message. You might want to
* use such a message to display e.g. status information from your game.
*